@@ -25,7 +25,7 @@ class BOTAN_DLL Keccak_1600 final : public HashFunction
       * @param output_bits the size of the hash output; must be one of
       *                    224, 256, 384, or 512
       */
-      Keccak_1600(size_t output_bits = 512);
+      explicit Keccak_1600(size_t output_bits = 512);
 
       size_t hash_block_size() const override { return m_bitrate / 8; }
       size_t output_length() const override { return m_output_bits / 8; }
@@ -33,6 +33,12 @@ class BOTAN_DLL Keccak_1600 final : public HashFunction
       HashFunction* clone() const override;
       std::string name() const override;
       void clear() override;
+
+      /**
+      * The bare Keccak-1600 permutation
+      */
+      static void permute(u64bit A[25]);
+
    private:
       void add_data(const byte input[], size_t length) override;
       void final_result(byte out[]) override;
